==> libpostal-1.1.tar.gz: libpostal-1.1/ISSUE_TEMPLATE.md <==
Hi!

I was checking out libpostal, and saw something that could be improved.

---
#### My country is
<!-- If you were Carmen Sandiego, where in the world would you be? -->

---
#### Here's how I'm using libpostal
<!-- Always interested to know how people use the library! What are you working on? Which orgnization? What's your use case? -->

---
#### Here's what I did
<!-- the input you used in the case of issues with results, your system configuration for compilation issues/bugs, etc. -->

---
#### Here's what I got
<!-- the output from the parser, normalization, deduping, make, etc. Try to paste the exact result/output. -->

---
#### Here's what I was expecting
<!-- what should the correct parse/output have been? Try to be specific. -->

---
#### For parsing issues, please answer "yes" or "no" to all that apply.

- Does the input address exist in [OpenStreetMap](https://openstreetmap.org)?
  <!-- yes/no. Provide a link if possible -->
- Do all the toponyms exist in OSM (city, state, region names, etc.)?
  <!-- yes/no -->
- If the address uses a rare/uncommon format, does changing the order of the fields yield the correct result?
  <!-- yes/no. Providing examples is useful. -->
- If the address does not contain city, region, etc., does adding those fields to the input improve the result?
  <!-- yes/no. Please paste any examples of forms of the address that do work. There might be an inconsistency between your address and libpostal's training addresses. -->
- If the address contains apartment/floor/sub-building information or uncommon formatting, does removing that help? Is there any minimum form of the address that gets the right parse?
  <!-- yes/no. Please paste any examples of forms of the address that do work. Trying to do some of this investigation yourself before asking for help can save time for maintainers and improve your understanding of the project. -->

---
#### Here's what I think could be improved
<!-- suggestions for what could be done differently -->

==> libpostal-1.1.3.tar.gz: libpostal-1.1.3/ISSUE_TEMPLATE.md <==
Hi!

I was checking out libpostal, and saw something that could be improved.

---
#### My country is
<!-- If you were Carmen Sandiego, where in the world would you be? -->

---
#### Here's how I'm using libpostal
<!-- Always interested to know how people use the library! What are you working on? Which organization? What's your use case? -->

---
#### Here's what I did
<!-- the input you used in the case of issues with results, your system configuration for compilation issues/bugs, etc. -->

---
#### Here's what I got
<!-- the output from the parser, normalization, deduping, make, etc. Try to paste the exact result/output. -->

---
#### Here's what I was expecting
<!-- what should the correct parse/output have been? Try to be specific. -->

---
#### For parsing issues, please answer "yes" or "no" to all that apply.

- Does the input address exist in [OpenStreetMap](https://openstreetmap.org)?
  <!-- yes/no. Provide a link if possible -->
- Do all the toponyms exist in OSM (city, state, region names, etc.)?
  <!-- yes/no -->
- If the address uses a rare/uncommon format, does changing the order of the fields yield the correct result?
  <!-- yes/no. Providing examples is useful. -->
- If the address does not contain city, region, etc., does adding those fields to the input improve the result?
  <!-- yes/no. Please paste any examples of forms of the address that do work. There might be an inconsistency between your address and libpostal's training addresses. -->
- If the address contains apartment/floor/sub-building information or uncommon formatting, does removing that help? Is there any minimum form of the address that gets the right parse?
  <!-- yes/no. Please paste any examples of forms of the address that do work. Trying to do some of this investigation yourself before asking for help can save time for maintainers and improve your understanding of the project. -->

---
#### Here's what I think could be improved
<!-- suggestions for what could be done differently -->
